/*
 * This file is part of Vanilla.
 *
 * Copyright (c) 2011 Spout LLC <http://www.spout.org/>
 * Vanilla is licensed under the Spout License Version 1.
 *
 * Vanilla is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * In addition, 180 days after any changes are published, you can use the
 * software, incorporating those changes, under the terms of the MIT license,
 * as described in the Spout License Version 1.
 *
 * Vanilla is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License,
 * the MIT license and the Spout License Version 1 along with this program.
 * If not, see <http://www.gnu.org/licenses/> for the GNU Lesser General Public
 * License and see <http://spout.in/licensev1> for the full license, including
 * the MIT license.
 */
package org.spout.vanilla.data.effect;

import java.util.HashMap;
import java.util.Map;

public enum EntityEffectType {
	SPEED(1, 2),
	SLOWNESS(2, 10),
	HASTE(3, 0),
	MINING_FATIGUE(4, 0),
	STRENGTH(5, 9),
	INSTANT_HEALTH(6, 5),
	INSTANT_DAMAGE(7, 12),
	JUMP_BOOST(8, 0),
	NAUSEA(9, 0),
	REGENERATION(10, 1),
	RESISTANCE(11, 0),
	FIRE_RESISTANCE(12, 3),
	WATER_BREATHING(13, 0),
	INVISIBILITY(14, 14),
	BLINDNESS(15, 0),
	NIGHT_VISION(16, 6),
	HUNGER(17, 0),
	WEAKNESS(18, 8),
	POISON(19, 4),
	WITHER(20, 0),
	NONE(0, 0);
	private final int id;
	private final int potionId;
	private static final Map<Integer, EntityEffectType> idMap = new HashMap<Integer, EntityEffectType>();

	static {
		for (EntityEffectType type : EntityEffectType.values()) {
			idMap.put(type.getId(), type);
		}
	}

	private EntityEffectType(int id, int potionId) {
		this.id = id;
		this.potionId = potionId;
	}

	public static EntityEffectType get(int id) {
		return idMap.get(id);
	}

	public int getId() {
		return id;
	}

	public int getPotionId() {
		return potionId;
	}

}
