/*
 * This file is part of Vanilla.
 *
 * Copyright (c) 2011 Spout LLC <http://www.spout.org/>
 * Vanilla is licensed under the Spout License Version 1.
 *
 * Vanilla is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * In addition, 180 days after any changes are published, you can use the
 * software, incorporating those changes, under the terms of the MIT license,
 * as described in the Spout License Version 1.
 *
 * Vanilla is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License,
 * the MIT license and the Spout License Version 1 along with this program.
 * If not, see <http://www.gnu.org/licenses/> for the GNU Lesser General Public
 * License and see <http://spout.in/licensev1> for the full license, including
 * the MIT license.
 */
package org.spout.vanilla.event.window;

import org.spout.api.event.HandlerList;
import org.spout.api.inventory.Inventory;
import org.spout.api.inventory.ItemStack;

import org.spout.vanilla.inventory.window.AbstractWindow;

public class WindowSlotEvent extends WindowEvent {
	private static final HandlerList handlers = new HandlerList();
	private final int slot;
	private final ItemStack item;
	private final Inventory inventory;

	public WindowSlotEvent(AbstractWindow window, Inventory inventory, int slot, ItemStack item) {
		super(window);
		this.inventory = inventory;
		this.slot = slot;
		this.item = item;
	}

	/**
	 * Gets the Inventory within the item got changed
	 *
	 * @return the Inventory of the item
	 */
	public Inventory getInventory() {
		return this.inventory;
	}

	/**
	 * Gets the slot of the Inventory that got changed
	 *
	 * @return changed slot relative to the Inventory
	 */
	public int getSlot() {
		return this.slot;
	}

	/**
	 * Gets the item the slot is set to
	 *
	 * @return the item
	 */
	public ItemStack getItem() {
		return this.item;
	}

	@Override
	public HandlerList getHandlers() {
		return handlers;
	}

	public static HandlerList getHandlerList() {
		return handlers;
	}
}
