/*
 * This file is part of Vanilla.
 *
 * Copyright (c) 2011 Spout LLC <http://www.spout.org/>
 * Vanilla is licensed under the Spout License Version 1.
 *
 * Vanilla is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * In addition, 180 days after any changes are published, you can use the
 * software, incorporating those changes, under the terms of the MIT license,
 * as described in the Spout License Version 1.
 *
 * Vanilla is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License,
 * the MIT license and the Spout License Version 1 along with this program.
 * If not, see <http://www.gnu.org/licenses/> for the GNU Lesser General Public
 * License and see <http://spout.in/licensev1> for the full license, including
 * the MIT license.
 */
package org.spout.vanilla.material.block.misc;

import org.spout.api.entity.Entity;
import org.spout.api.event.player.Action;
import org.spout.api.geo.cuboid.Block;
import org.spout.api.material.block.BlockFace;

import org.spout.vanilla.data.resources.VanillaMaterialModels;
import org.spout.vanilla.material.VanillaMaterials;
import org.spout.vanilla.material.block.Solid;

public class CakeBlock extends Solid {
	public CakeBlock(String name, int id) {
		super(name, id, VanillaMaterialModels.CAKE_BLOCK);
		this.setHardness(0.5F).setResistance(2.5F).setTransparent();
		this.getDrops().clear();
	}

	@Override
	public void onInteractBy(Entity entity, Block block, Action type, BlockFace clickedface) {
		if (type == Action.RIGHT_CLICK) {
			if (block.getBlockData() == CakeSize.ONE_PIECE.getData()) {
				// Cake has been fully eaten
				block.setMaterial(VanillaMaterials.AIR);
			} else {
				setSize(block, CakeSize.getByData((short) (getSize(block).getData() + 1)));
			}
		}
	}

	/**
	 * Returns the {@link CakeSize} of this cake material.
	 *
	 * @param block Block with this cake material
	 * @return Size of this material
	 */
	public CakeSize getSize(Block block) {
		return CakeSize.getByData(block.getBlockData());
	}

	/**
	 * Sets the {@link CakeSize} of this cake material.
	 *
	 * @param block Block with this cake material
	 * @param size Size to set
	 */
	public void setSize(Block block, CakeSize size) {
		block.setData(size.getData());
	}

	/**
	 * Represents the size of a cake material.
	 */
	public enum CakeSize {
		FULL(0x0),
		FIVE_PIECES(0x1),
		FOUR_PIECES(0x2),
		THREE_PIECES(0x3),
		TWO_PIECES(0x4),
		ONE_PIECE(0x5);
		private final short data;

		private CakeSize(int data) {
			this.data = (short) data;
		}

		public short getData() {
			return data;
		}

		public static CakeSize getByData(short data) {
			for (CakeSize size : CakeSize.values()) {
				if (size.data == data) {
					return size;
				}
			}

			return null;
		}
	}
}
