/*
 * This file is part of Vanilla.
 *
 * Copyright (c) 2011 Spout LLC <http://www.spout.org/>
 * Vanilla is licensed under the Spout License Version 1.
 *
 * Vanilla is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * In addition, 180 days after any changes are published, you can use the
 * software, incorporating those changes, under the terms of the MIT license,
 * as described in the Spout License Version 1.
 *
 * Vanilla is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License,
 * the MIT license and the Spout License Version 1 along with this program.
 * If not, see <http://www.gnu.org/licenses/> for the GNU Lesser General Public
 * License and see <http://spout.in/licensev1> for the full license, including
 * the MIT license.
 */
package org.spout.vanilla.material.item.bucket;

import org.spout.api.entity.Entity;
import org.spout.api.event.Cause;
import org.spout.api.event.player.Action;
import org.spout.api.geo.cuboid.Block;
import org.spout.api.inventory.ItemStack;
import org.spout.api.inventory.Slot;
import org.spout.api.material.BlockMaterial;
import org.spout.api.material.block.BlockFace;

import org.spout.math.vector.Vector3f;
import org.spout.vanilla.material.VanillaMaterials;
import org.spout.vanilla.material.block.liquid.Water;
import org.spout.vanilla.material.item.BlockItem;
import org.spout.vanilla.util.PlayerUtil;
import org.spout.vanilla.world.generator.VanillaGenerators;

public class FullBucket extends BlockItem {
	public FullBucket(String name, int id, BlockMaterial place) {
		super(name, id, place, null);
	}

	@Override
	public void onInteract(Entity entity, Block block, Action type, BlockFace face) {
		super.onInteract(entity, block, type, face);
		if (type == Action.RIGHT_CLICK) {
			Slot inv = PlayerUtil.getHeldSlot(entity);
			if (inv != null && !PlayerUtil.isCostSuppressed(entity)) {
				inv.set(new ItemStack(VanillaMaterials.BUCKET, 1));
			}
		}
	}

	@Override
	public boolean canPlace(Block block, short data, BlockFace against, Vector3f clickedPos, boolean isClickedBlock, Cause<?> cause) {
		boolean success = super.canPlace(block, data, against, clickedPos, isClickedBlock, cause);
		if (success) {
			if (VanillaGenerators.NETHER.equals(block.getWorld().getGenerator()) && getPlacedMaterial() instanceof Water) {
				return false;
			}
		}
		return success;
	}
}
