/*
 * This file is part of Vanilla.
 *
 * Copyright (c) 2011 Spout LLC <http://www.spout.org/>
 * Vanilla is licensed under the Spout License Version 1.
 *
 * Vanilla is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * In addition, 180 days after any changes are published, you can use the
 * software, incorporating those changes, under the terms of the MIT license,
 * as described in the Spout License Version 1.
 *
 * Vanilla is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License,
 * the MIT license and the Spout License Version 1 along with this program.
 * If not, see <http://www.gnu.org/licenses/> for the GNU Lesser General Public
 * License and see <http://spout.in/licensev1> for the full license, including
 * the MIT license.
 */
package org.spout.vanilla.world.generator.normal.object.tree;

import java.util.Random;

import org.spout.api.geo.World;
import org.spout.api.material.BlockMaterial;

import org.spout.vanilla.material.VanillaMaterials;
import org.spout.vanilla.material.block.Liquid;
import org.spout.vanilla.material.block.Solid;

public class ShrubObject extends TreeObject {
	// size control
	private byte radius = 2;

	public ShrubObject() {
		this(null);
	}

	public ShrubObject(Random random) {
		super(random, (byte) 1, (byte) 1, (short) 3, (short) 0);
		overridable.add(VanillaMaterials.AIR);
		overridable.add(VanillaMaterials.LEAVES);
	}

	@Override
	public boolean canPlaceObject(World w, int x, int y, int z) {
		if (!super.canPlaceObject(w, x, y, z)) {
			return false;
		}
		return !(w.getBlockMaterial(x, y, z) instanceof Liquid
				|| w.getBlockMaterial(x, y + 1, z) instanceof Liquid);
	}

	@Override
	public void placeObject(World w, int x, int y, int z) {
		w.setBlockMaterial(x, y - 1, z, VanillaMaterials.DIRT, (short) 0, null);
		for (byte yy = 0; yy < totalHeight; yy++) {
			w.setBlockMaterial(x, y + yy, z, VanillaMaterials.LOG, logMetadata, null);
		}
		for (byte yy = radius; yy > -1; yy--) {
			for (byte xx = (byte) -yy; xx < yy + 1; xx++) {
				for (byte zz = (byte) -yy; zz < yy + 1; zz++) {
					if (Math.abs(xx) == yy && Math.abs(zz) == yy && random.nextBoolean()) {
						continue;
					}
					final BlockMaterial material = w.getBlockMaterial(x + xx, y - yy + radius, z + zz);
					if (!(material instanceof Solid || material instanceof Liquid)) {
						w.setBlockMaterial(x + xx, y - yy + radius, z + zz, VanillaMaterials.LEAVES, leavesMetadata, null);
					}
				}
			}
		}
	}

	public void setRadius(byte radius) {
		this.radius = radius;
	}
}
